@@ -1,5 +1,5 @@
 from .bigcodebench.main import BigCodeBenchComplete_Benchmark
-from .bigcodebench.single_step_dag import code_problem_single_step
+from .bigcodebench.dags.single_step_dag import code_problem_single_step
 
 from .gradeschool_math.main import GSM8k_Benchmark
 from .gradeschool_math.dags.single_step import gsm8k_single_step_example
