@@ -4,8 +4,10 @@ from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
 from pydantic import BaseModel
 
+#from apropos.src.core.lms.helpers import LLM
+from zyk import LM
+
 from apropos.src.bench.base import Benchmark
-from apropos.src.core.lms.helpers import LLM
 from apropos.src.core.programs.convenience_functions.dag_constructors import (
     build_single_step_program,
 )
@@ -36,7 +38,7 @@ class TopicResponse(BaseModel):
 
 
 async def get_topics_for_prompt(
-    prompt: str, other_prompts: List[str], llm: LLM
+    prompt: str, other_prompts: List[str], llm: LM
 ) -> List[TopicInfo]:
     system_message = """
 Please review the provided prompt section and break it down into a sequential series of topics.
@@ -77,7 +79,7 @@ Do not include content that varies between prompt instances in your topics.
 
 Your topics: """
 
-    topic_response = await llm.async_respond(
+    topic_response = await llm.respond_async(
         system_prompt=system_message,
         user_prompt=user_message,
         response_model=TopicResponse,
@@ -105,7 +107,7 @@ class TopicBreakdownResponse(BaseModel):
 
 
 async def assign_topics_to_prompt_section(
-    prompt: str, topics: str, llm: LLM
+    prompt: str, topics: str, llm: LM
 ) -> List[str]:
     system_message = """
 You'll be provided with a prompt and a number of topics that have been identified within it.
@@ -125,7 +127,7 @@ Please break down the prompt into the following three sections:
 {topics_by_index}
 </Topics By Index>
 """
-    assignments = await llm.async_respond(
+    assignments = await llm.respond_async(
         system_prompt=system_message,
         user_prompt=user_message,
         response_model=TopicBreakdownResponse,
@@ -153,7 +155,7 @@ async def break_down_prompt_content_for_topic_into_components(
     main_prompt_instance: str,
     prompt_instances: List[str],
     topic_info: TopicInfo,
-    llm: LLM,
+    llm: LM,
 ) -> Topic:
     system_message = """
 You'll be provided with a prompt and a section within it that's be highlighted as a topic.
@@ -201,7 +203,7 @@ Output:
 {additional_prompt_instances}
 """
 
-    breakdown = await llm.async_respond(
+    breakdown = await llm.respond_async(
         system_prompt=system_message,
         user_prompt=user_message,
         response_model=BreakdownFieldsResponse,
@@ -223,7 +225,7 @@ async def build_prompt_template(
     system_prompt_instances: List[str],
     user_prompt_instances: List[str],
     response_model: Union[str, BaseModel],
-    llm: LLM,
+    llm: LM,
 ):
     # One LM to split the prompt into topics
     system_topics = await get_topics_for_prompt(
@@ -288,7 +290,7 @@ class AliasesToPromptInputs(BaseModel):
 
 
 async def match_aliases_to_prompt_template_inputs(
-    aliases: List[str], prompt_template: PromptTemplate, llm: LLM
+    aliases: List[str], prompt_template: PromptTemplate, llm: LM
 ) -> Dict[str, str]:
     system_message = """
 You'll be provided with a list of aliases, along with inputs to a prompt template.
@@ -301,7 +303,7 @@ Please match the aliases to the prompt template inputs by providing a mapping fr
 # Prompt Template
 {prompt_template}
 """
-    response = await llm.async_respond(
+    response = await llm.respond_async(
         system_prompt=system_message,
         user_prompt=user_message,
         response_model=AliasesToPromptInputs,
@@ -320,8 +322,8 @@ async def ground_program_to_single_step_dag(
     system_prompt_instances: List[str],
     user_prompt_instances: List[str],
     response_model: Union[str, BaseModel],
-    ground_llm: LLM,
-    program_llm: LLM,
+    ground_llm: LM,
+    program_llm: LM,
 ) -> Tuple[PromptTemplate, LM_DAG]:
     prompt_template = await build_prompt_template(
         name_for_prompt,
@@ -464,8 +466,8 @@ async def messages_to_dag_and_benchmark(
     metric: Metric,
     input_keys: List[str],
     prompt_name: str,
-    ground_llm: LLM,
-    program_llm: LLM,
+    ground_llm: LM,
+    program_llm: LM,
 ) -> Tuple[LM_DAG, Benchmark]:
     template, dag = await ground_program_to_single_step_dag(
         name_for_prompt=prompt_name,
